yt.visualization.volume_rendering.camera.PerspectiveCamera.yaw — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.camera.PerspectiveCamera.yaw

`PerspectiveCamera.` `yaw`(theta, rot_center)

  Rotate by a given angle about the vertical axis through the point center. This is accomplished by rotating the focal point and then setting the looking vector to point to the center.

  Yaw the view.

  Parameters: | theta : float, in radians Angle (in radians) by which to yaw the view. center : a tuple (x, y, z) The point to rotate about

  Examples

      >>> cam.yaw(np.pi/4, (0., 0., 0.))